mypack

package
v0.0.0-...-db6da08 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 30, 2020 License: MIT Imports: 0 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetName

func GetName() string

GetName is an example of funcion inside a package First letter in function name should be uppercase for function to be exported Functions, Types, or even Type fields which start with lowercase letters will be private

Types

This section is empty.

Jump to